@@ -1,6 +1,5 @@
-(* $I1: Unison file synchronizer: src/globals.ml $ *)
-(* $I2: Last modified by bcpierce on Mon, 06 Sep 2004 14:48:05 -0400 $ *)
-(* $I3: Copyright 1999-2004 (see COPYING for details) $ *)
+(* Unison file synchronizer: src/globals.ml *)
+(* Copyright 1999-2007 (see COPYING for details) *)
 
 open Common
 
@@ -203,6 +202,14 @@ let batch =
      ^ "interface will ask no questions at all.  Non-conflicting changes "
      ^ "will be propagated; conflicts will be skipped.")
 
+let confirmBigDeletes =
+  Prefs.createBool "confirmbigdeletes" true "request confirmation for whole-replica deletes"
+    ("When this is set to {\\tt true}, Unison will request an extra confirmation if it appears "
+     ^ "that the entire replica has been deleted, before propagating the change.  If the {\\tt batch} "
+     ^ "flag is also set, synchronization will be aborted.  When the {\\tt path} preference is used, "
+     ^ "the same confirmation will be requested for top-level paths.  (At the moment, this flag only "
+     ^ "affects the text user interface.)  See also the {\\tt mountpoint} preference.")
+
 let ignore =
   Pred.create "ignore"
     ("Including the preference \\texttt{-ignore \\ARG{pathspec}} causes Unison to "
@@ -237,6 +244,11 @@ let shouldIgnore p =
   let p = Path.toString p in
   (Pred.test ignore p) && not (Pred.test ignorenot p) 
 
+let addRegexpToIgnore re =
+  let oldRE = Pred.extern ignore in
+  let newRE = re::oldRE in
+  Pred.intern ignore newRE
+
 let merge = 
   Pred.create "merge"
     ("This preference can be used to run a merge program which will create "
@@ -249,21 +261,12 @@ let merge =
      ^ "details on Merging functions are present in "
      ^ "\\sectionref{merge}{Merging files}.")
         
-let mergebatch = 
-  Pred.create "mergebatch"
-    ("Normally, when Unison is run with the {\\tt batch} flag set to true, it does not "
-     ^ "invoke any external merge programs.  To tell it that a given file can be merged "
-     ^ "even when in batch mode, use the {\\tt mergebatch} preference instead of "
-     ^ "{\\tt merge}.  When running in non-batch mode, the {\\tt merge} preference is used "
-     ^ "instead of {\\tt mergebatch} if both are specified for a given path.")
-        
-let shouldMerge p =
-     Pred.test mergebatch (Path.toString p)
-  || (not (Prefs.read batch) && Pred.test merge (Path.toString p))
+let shouldMerge p = Pred.test merge (Path.toString p)
 
-let mergeCmdForPath p =
-  if Prefs.read batch then
-    Pred.assoc mergebatch (Path.toString p)
-  else
-    try Pred.assoc merge (Path.toString p)
-    with Not_found -> Pred.assoc mergebatch (Path.toString p)
+let mergeCmdForPath p = Pred.assoc merge (Path.toString p)
+
+let someHostIsRunningWindows =
+  Prefs.createBool "someHostIsRunningWindows" false "*" ""
+
+let allHostsAreRunningWindows =
+  Prefs.createBool "allHostsAreRunningWindows" false "*" ""
